==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/af-ZA/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Bates toegewys aan: naam',
    'bulk_update_warn'	=> 'Jy is op die punt om die eienskappe van gebruikers_count gebruikers te wysig. Hou daar rekening mee dat u nie u eie gebruikers eienskappe kan verander deur hierdie vorm te gebruik en u eie gebruikers afzonderlijk moet wysig.',
    'bulk_update_help'	=> 'Met hierdie vorm kan u verskeie gebruikers gelyktydig bywerk. Vul slegs die velde in wat u moet verander. Enige velde wat leeg is, bly onveranderd.',
    'current_assets'    => 'Bates wat tans na hierdie gebruiker gekontroleer word',
    'clone'             => 'Klone gebruiker',
    'contact_user'      => 'Kontak naam',
    'edit'              => 'Wysig gebruiker',
    'filetype_info'     => 'Toegelate filetipes is png, gif, jpg, jpeg, doc, docx, pdf, txt, zip en rar.',
    'history_user'      => 'Geskiedenis vir: naam',
    'info'				=> 'info',
    'restore_user'		=> 'Klik hier om dit te herstel.',
    'last_login'        => 'Laaste Aanmelding',
    'ldap_config_text'  => 'LDAP-konfigurasie-instellings kan Admin> Instellings gevind word. Die (opsionele) gekose ligging sal vir alle ingevoerde gebruikers gestel word.',
    'print_assigned'    => 'Print All Assigned',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Sagteware Uitgesoek na: naam',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Sien gebruiker: naam',
    'usercsv'           => 'CSV-lêer',
    'two_factor_admin_optin_help' => 'Jou huidige administrasie-instellings laat selektiewe handhawing van twee-faktor-verifikasie toe.',
    'two_factor_enrolled' => '2FA-toestel ingeskryf',
    'two_factor_active'   => '2FA aktief',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/af-ZA/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Bates toegewys aan: naam',
    'bulk_update_warn'	=> 'Jy is op die punt om die eienskappe van gebruikers_count gebruikers te wysig. Hou daar rekening mee dat u nie u eie gebruikers eienskappe kan verander deur hierdie vorm te gebruik en u eie gebruikers afzonderlijk moet wysig.',
    'bulk_update_help'	=> 'Met hierdie vorm kan u verskeie gebruikers gelyktydig bywerk. Vul slegs die velde in wat u moet verander. Enige velde wat leeg is, bly onveranderd.',
    'current_assets'    => 'Bates wat tans na hierdie gebruiker gekontroleer word',
    'clone'             => 'Klone gebruiker',
    'contact_user'      => 'Kontak naam',
    'edit'              => 'Wysig gebruiker',
    'filetype_info'     => 'Toegelate filetipes is png, gif, jpg, jpeg, doc, docx, pdf, txt, zip en rar.',
    'history_user'      => 'Geskiedenis vir: naam',
    'info'				=> 'info',
    'restore_user'		=> 'Klik hier om dit te herstel.',
    'last_login'        => 'Laaste Aanmelding',
    'ldap_config_text'  => 'LDAP-konfigurasie-instellings kan Admin> Instellings gevind word. Die (opsionele) gekose ligging sal vir alle ingevoerde gebruikers gestel word.',
    'print_assigned'    => 'Print All Assigned',
    'email_assigned'    => 'Email List of All Assigned',
    'user_notified'     => 'User has been emailed a list of their currently assigned items.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Include this user when auto-assigning eligible licenses',
    'auto_assign_help'  => 'Skip this user in auto assignment of licenses',
    'software_user'     => 'Sagteware Uitgesoek na: naam',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Sien gebruiker: naam',
    'usercsv'           => 'CSV-lêer',
    'two_factor_admin_optin_help' => 'Jou huidige administrasie-instellings laat selektiewe handhawing van twee-faktor-verifikasie toe.',
    'two_factor_enrolled' => '2FA-toestel ingeskryf',
    'two_factor_active'   => '2FA aktief',
    'user_deactivated'  => 'User cannot login',
    'user_activated'  => 'User can login',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion_information' => 'You are about to checkin ALL items from the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_assets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
    'remote_label'   => 'This is a remote user',
    'remote'   => 'Remote',
    'remote_help' => 'This can be useful if you need to filter by remote users who never or rarely come into your physical locations.',
    'not_remote_label' => 'This is not a remote user',
    'vip_label' => 'VIP user',
    'vip_help' => 'This can be helpful to mark important people in your org if you would like to handle them in special ways.',
    'create_user' => 'Create a user',
    'create_user_page_explanation' => 'This is the account information you will use to access the site for the first time.',
    'email_credentials' => 'Email credentials',
    'email_credentials_text' => 'Email my credentials to the email address above',
    'next_save_user' => 'Next: Save User',
    'all_assigned_list_generation' => 'Generated on:',
    'email_user_creds_on_create' => 'Email this user their credentials?',
];
